# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-01 02:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('papertrail', '0002_auto_20160125_1711'),
    ]

    operations = [
        migrations.AlterField(
            model_name='entry',
            name='message',
            field=models.TextField(),
        ),
    ]
